@@ -1,6 +1,9 @@
 from bs4 import BeautifulSoup, Comment
 from collections import Counter
 import pyap, re, requests
+from urllib.parse import urljoin
+
+headers = { "User-Agent": "Mozilla/5.0"}
 
 def visiableText(page):
     soup = BeautifulSoup(page, 'lxml')
@@ -53,12 +56,13 @@ def parse(page,domain=''):
       for social in ['facebook', 'twitter', 'instagram','linkedin']:
         result[social] = ([l for l in allLinks if social in l]+[''])[0]
       if not domain:
-        domain = Counter([toDomain(l) for l in allLinks]).most_common(1)[0][0]
+        domain = Counter([toDomain(l) for l in allLinks if 'facebook' not in l and 'twitter' not in l and 'linkedin' not in l]).most_common(1)[0][0]
       else:
         domain = toDomain(domain)
 
-      innerLinks = [f'http://{domain}'+s if s.startswith('/') else s for s in allLinks if s.startswith('/') or domain in s]
-      result['contactLink'] = ([l for l in innerLinks if 'contact' in l.lower() or 'location' in l.lower()] + [''])[0]
+      # innerLinks = [f'http://{domain}'+s if s.startswith('/') else s for s in allLinks if s.startswith('/') or domain in s]
+      innerLinks = [urljoin(f'http://{domain}',s) if 'http' not in s else s for s in allLinks if 'http' not in s or domain in s]
+      result['contactLink'] = ([l for l in innerLinks if 'contact' in l.lower() or 'contato' in l.lower() or 'kontakt' in l.lower() or 'location' in l.lower()] + [''])[0]
       result['aboutLink'] = ([l for l in innerLinks if 'about' in l.lower()] + [''])[0]
 
     result['title'] = soup.find('title').text.replace('\n','').strip() if soup.find('title') else ''
@@ -69,7 +73,18 @@ def parse(page,domain=''):
 
     if not addresses and result['aboutLink']:
       try:
-        res = requests.get(result['aboutLink'])
+        res = requests.get(result['aboutLink'], timeout=20, headers=headers)
+        resvis = visiableText(res.content)
+        addresses = pyap.parse(resvis, country='CA')
+        addresses += pyap.parse(resvis, country='US')
+        addressesNoAnd = [a for a in addresses if not re.findall(r'\band\b', str(a), re.I)]
+        if len(addressesNoAnd)>1:
+          addresses = addressesNoAnd
+      except Exception as e:
+        pass
+    if not addresses and result['contactLink']:
+      try:
+        res = requests.get(result['contactLink'], timeout=20, headers=headers)
         resvis = visiableText(res.content)
         addresses = pyap.parse(resvis, country='CA')
         addresses += pyap.parse(resvis, country='US')
@@ -83,7 +98,7 @@ def parse(page,domain=''):
       names = re.findall(namepattern, result['title'], re.I)
     elif result['aboutLink']  and namepattern:
       try:
-        aboutres = requests.get(result['aboutLink'])
+        aboutres = requests.get(result['aboutLink'], timeout=20, headers=headers)
         aboutvis = visiableText(aboutres.content)
         names = re.findall(namepattern, aboutvis, re.I)
       except:
@@ -104,6 +119,6 @@ def parse(page,domain=''):
 
 
 if __name__ == '__main__':
-  res = requests.get('https://goodprice.com')
-  result = parse(res.content)
+  res = requests.get('http://fastsoft.net', timeout=20, headers=headers)
+  result = parse(res.content,domain='fastsoft.net')
   print(result)
\ No newline at end of file
